@@ -1,5 +1,5 @@
 from fabric import api as fab
-from os.path import exists
+from os.path import exists, join
 from contrib.django import DjangoFabric
 from contrib.virtualenv import VirtualenvFabric
 
@@ -15,16 +15,29 @@ class BaseFabric(object):
     search_exclude_patterns = [".pyc", ".svn", ".tmp_"]
 
     def __init__(self):
-        fab.hosts = self.hosts
+        fab.env.hosts = self.hosts
 
-    def _remote(self):
+    def is_remote(self):
         '''
         Returns true if we run fabfile remotely.
         Script check existing local_project_path directory
         '''
         return not exists(self.local_project_path)
 
-    def search(self, string=''):
+    @property
+    def project_path(self):
+        '''
+        Returns project path (dep or dev) depends on current directory sctructure
+        '''
+        return self.remote_project_path if self.is_remote() else self.local_project_path
+
+    def project_path_join(self, *args):
+        '''
+        Regular os.path.join() with prepended project_path
+        '''
+        return join(self.project_path, *args)
+
+    def fab_search(self, string=''):
         '''
         Search string amoung source code inside directories from `search_dirs` property
         '''
@@ -34,7 +47,7 @@ class BaseFabric(object):
             'exclude': '| ' + ' | '.join(['grep -v "%s"' % pattern for pattern in self.search_exclude_patterns]) if len(self.search_exclude_patterns) else '',
         }, capture=False)
 
-    def del_pyc(self):
+    def fab_del_pyc(self):
         '''
         Remove all .pyc files inside in fabfile and child directories
         '''
