@@ -1,30 +1,42 @@
-from fabric.api import local, run
+from fabric.api import local, run, cd
+from os.path import join
 import re
 
+'''
+TODO: move checking use_virtualenv to decorator of method and decide where to keep this decorator
+local_manage, run_manage and run_pip - same logic
+'''
+
 class DjangoFabric(object):
     '''
     Fabric command file with base django's manage.py commands
     '''
-    managefile_path = './manage.py'
+    manage_file = './manage.py'
     test_default_app = None
     test_settings = None
     shell_plus = False
     devserver_port = 8000
 
+    # fixtures properties
+    fixtures_dir = 'fixtures'
+    fixtures_format = 'json'
+    fixtures_map = (
+        'sites.site',
+    )
+
     def local_manage(self, command):
         '''
         Run manage.py on development
         '''
         if getattr(self, 'use_virtualenv', False):
-            # use virtualenv context manager
             with self.virtualenv():
                 local('%(manage)s %(command)s' % {
-                    'manage': self.managefile_path,
+                    'manage': self.manage_file,
                     'command': command,
                 }, capture=False)
         else:
             local('%(manage)s %(command)s' % {
-                'manage': self.managefile_path,
+                'manage': self.manage_file,
                 'command': command,
             }, capture=False)
 
@@ -33,15 +45,14 @@ class DjangoFabric(object):
         Run manage.py on production
         '''
         if getattr(self, 'use_virtualenv', False):
-            # use virtualenv context manager
             with self.virtualenv(remote=True):
                 run('%(manage)s %(command)s' % {
-                    'manage': self.managefile_path,
+                    'manage': self.manage_file,
                     'command': command,
                 })
         else:
             run('%(manage)s %(command)s' % {
-                'manage': self.managefile_path,
+                'manage': self.manage_file,
                 'command': command,
             })
 
@@ -76,4 +87,21 @@ class DjangoFabric(object):
         self.local_manage('test %(name)s %(settings)s' % {
             'name': test_name,
             'settings': ('--settings=%s' % self.test_settings) if self.test_settings else '',
-        })
\ No newline at end of file
+        })
+
+    def get_fixtures_file(self, model):
+        return join(self.fixtures_dir, '.'.join([model, self.fixtures_format]))
+
+    def fab_update_fixtures(self):
+        '''
+        Put remote fixtures to repository on production, get and load them on development
+        '''
+        with cd(self.remote_project_path):
+            for model in self.fixtures_map:
+                self.run_manage('dumpdata --format=%s %s > %s' % (self.fixtures_format, model, self.get_fixtures_file(model)))
+            run('git add %s' % self.fixtures_dir)
+            run('git commit -m "updated fixtures"')
+            run('git push')
+        local('git pull', capture=False)
+        for model in self.fixtures_map:
+            self.local_manage('loaddata %s' % self.get_fixtures_file(model))
\ No newline at end of file
